Module signing

Module signing 

Transaction signing utilities for Accumulate protocol

This module implements proper binary encoding for transaction signing matching the Go core and Dart SDK implementations.

Modules

account_auth_op_types
AccountAuthOperation type constants (matches Go AccountAuthOperationType)
key_page_op_types
KeyPageOperation type enum values matching Go core From protocol/key_page_operations.yml
signature_types
Signature type enum values matching Go core
tx_types
Transaction type enum values matching Go core

Structs

HeaderBinaryOptions
Options for extended transaction header fields (fields 5-7).

Functions

compute_ed25519_signature_metadata_hash
Compute signature metadata hash for ED25519 signatures
compute_signature_metadata_hash
Compute signature metadata hash for any signature type
compute_transaction_hash
Compute transaction hash using binary encoding
compute_write_data_body_hash
Compute WriteData body hash using special Merkle algorithm
compute_write_data_to_body_hash
Compute WriteDataTo body hash using special Merkle algorithm
create_signing_preimage
Create signing preimage
marshal_add_credits_body
Marshal AddCredits transaction body to binary format
marshal_burn_credits_body
Marshal BurnCredits transaction body to binary format
marshal_burn_tokens_body
Marshal BurnTokens transaction body to binary format
marshal_create_data_account_body
Marshal CreateDataAccount transaction body to binary format
marshal_create_identity_body
Marshal CreateIdentity transaction body to binary format
marshal_create_key_book_body
Marshal CreateKeyBook transaction body to binary format
marshal_create_key_page_body
Marshal CreateKeyPage transaction body to binary format
marshal_create_token_account_body
Marshal CreateTokenAccount transaction body to binary format
marshal_create_token_body
Marshal CreateToken transaction body to binary format
marshal_issue_tokens_body
Marshal IssueTokens transaction body to binary format
marshal_key_page_operation
Marshal a KeyPageOperation to binary format
marshal_key_spec_params
Marshal KeySpecParams to binary format
marshal_lock_account_body
Marshal LockAccount transaction body to binary format
marshal_send_tokens_body
Marshal SendTokens transaction body to binary format
marshal_transaction_header
Marshal transaction header to binary format
marshal_transaction_header_full
Marshal transaction header with all fields including extended options (fields 5-7).
marshal_transfer_credits_body
Marshal TransferCredits transaction body to binary format
marshal_update_account_auth_body
Marshal UpdateAccountAuth transaction body to binary format
marshal_update_key_body
Marshal UpdateKey transaction body to binary format
marshal_update_key_page_body
Marshal UpdateKeyPage transaction body to binary format
marshal_write_data_body
Marshal WriteData transaction body to binary format
marshal_write_data_to_body
Marshal WriteDataTo transaction body to binary format
sha256_bytes
SHA256 hash helper