pub struct SignatureSetWithThreshold {
pub inner: SignatureSet,
pub threshold: u32,
}Expand description
Extended SignatureSet with threshold for runtime validation Since the generated SignatureSet doesn’t have a threshold field in the YAML, we’ll simulate threshold semantics by treating all signatures as requiring consensus
Fields
inner: SignatureSetthreshold: u32Implementations
Sourceimpl SignatureSetWithThreshold
impl SignatureSetWithThreshold
pub fn new(inner: SignatureSet, threshold: u32) -> Result<Self, SigRuntimeError>