Transaction signing utilities for Accumulate protocol
This module implements proper binary encoding for transaction signing matching the Go core and Dart SDK implementations.
Modules
- account_
auth_ op_ types - AccountAuthOperation type constants (matches Go AccountAuthOperationType)
- key_
page_ op_ types - KeyPageOperation type enum values matching Go core From protocol/key_page_operations.yml
- signature_
types - Signature type enum values matching Go core
- tx_
types - Transaction type enum values matching Go core
Structs
- Header
Binary Options - Options for extended transaction header fields (fields 5-7).
Functions
- compute_
ed25519_ signature_ metadata_ hash - Compute signature metadata hash for ED25519 signatures
- compute_
signature_ metadata_ hash - Compute signature metadata hash for any signature type
- compute_
transaction_ hash - Compute transaction hash using binary encoding
- compute_
write_ data_ body_ hash - Compute WriteData body hash using special Merkle algorithm
- compute_
write_ data_ to_ body_ hash - Compute WriteDataTo body hash using special Merkle algorithm
- create_
signing_ preimage - Create signing preimage
- marshal_
add_ credits_ body - Marshal AddCredits transaction body to binary format
- marshal_
burn_ credits_ body - Marshal BurnCredits transaction body to binary format
- marshal_
burn_ tokens_ body - Marshal BurnTokens transaction body to binary format
- marshal_
create_ data_ account_ body - Marshal CreateDataAccount transaction body to binary format
- marshal_
create_ identity_ body - Marshal CreateIdentity transaction body to binary format
- marshal_
create_ key_ book_ body - Marshal CreateKeyBook transaction body to binary format
- marshal_
create_ key_ page_ body - Marshal CreateKeyPage transaction body to binary format
- marshal_
create_ token_ account_ body - Marshal CreateTokenAccount transaction body to binary format
- marshal_
create_ token_ body - Marshal CreateToken transaction body to binary format
- marshal_
issue_ tokens_ body - Marshal IssueTokens transaction body to binary format
- marshal_
key_ page_ operation - Marshal a KeyPageOperation to binary format
- marshal_
key_ spec_ params - Marshal KeySpecParams to binary format
- marshal_
lock_ account_ body - Marshal LockAccount transaction body to binary format
- marshal_
send_ tokens_ body - Marshal SendTokens transaction body to binary format
- marshal_
transaction_ header - Marshal transaction header to binary format
- marshal_
transaction_ header_ full - Marshal transaction header with all fields including extended options (fields 5-7).
- marshal_
transfer_ credits_ body - Marshal TransferCredits transaction body to binary format
- marshal_
update_ account_ auth_ body - Marshal UpdateAccountAuth transaction body to binary format
- marshal_
update_ key_ body - Marshal UpdateKey transaction body to binary format
- marshal_
update_ key_ page_ body - Marshal UpdateKeyPage transaction body to binary format
- marshal_
write_ data_ body - Marshal WriteData transaction body to binary format
- marshal_
write_ data_ to_ body - Marshal WriteDataTo transaction body to binary format
- sha256_
bytes - SHA256 hash helper